using System;
using System.Collections.Generic;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Shapes;
using System.Windows.Threading;
using Microsoft.Surface;
using Microsoft.Surface.Presentation;
using Microsoft.Surface.Presentation.Controls;
using HTPAPI;

namespace HTPBehaviorLab
{
    /// <summary>
    /// Interaction logic for SurfaceWindow1.xaml
    /// </summary>
    public partial class SurfaceWindow1 : SurfaceWindow
    {
        HTPManager m = new HTPManager();
        SoftnessBehavior softness = new SoftnessBehavior(0);
        BreakyBehavior breaky = new BreakyBehavior(0);
        OscillationBehavior oscillation = new OscillationBehavior(0);
        IntensityBehavior intensity = new IntensityBehavior(0);
        HTP h;
        HTP f;

        /// <summary>
        /// Default constructor.
        /// </summary>
        public SurfaceWindow1()
        {
            InitializeComponent();

            // Add handlers for Application activation events
            AddActivationHandlers();

            m.RegisterWindow(this, LayoutRoot);

            HTPShape shapebox = new HTPShape(this.shape);
            shapebox.AddHeightBehavior(this.softness);
            shapebox.AddHeightBehavior(this.breaky);
            shapebox.AddHeightBehavior(this.oscillation);
            shapebox.AddHeightBehavior(this.intensity);

            m.RegisterWidget(shapebox);

            behaviorBox1.Behavior = softness;
            behaviorBox2.Behavior = breaky;
            behaviorBox3.Behavior = oscillation;
            behaviorBox4.Behavior = intensity;

            this.breaky.Ratio = 0;
            this.softness.Ratio = 0;
            this.intensity.Ratio = 0;
            this.oscillation.Ratio = 0;

            f = m.GetHTP(0xCE);
            h = m.GetHTP(0xEF);

            h.HitTestEnabled = false;
            f.HitTestEnabled = false;

            h.AddHeightBehavior(new SoftnessBehavior(0.9));
            f.AddHeightBehavior(new SoftnessBehavior(0.7));

            h.StartHapticLoop();
            f.StartHapticLoop();

            f.HTPDown += new HTPEventHandler(h_HTPDown);
            h.HTPDown += new HTPEventHandler(h_HTPDown);
        }

        void h_HTPDown(object sender, HTPEventArgs e)
        {
            this.placeText.Visibility = Visibility.Hidden;
        }


        /// <summary>
        /// Occurs when the window is about to close. 
        /// </summary>
        /// <param name="e"></param>
        protected override void OnClosed(EventArgs e)
        {
            base.OnClosed(e);

            // Remove handlers for Application activation events
            RemoveActivationHandlers();
        }

        /// <summary>
        /// Adds handlers for Application activation events.
        /// </summary>
        private void AddActivationHandlers()
        {
            // Subscribe to surface application activation events
            ApplicationLauncher.ApplicationActivated += OnApplicationActivated;
            ApplicationLauncher.ApplicationPreviewed += OnApplicationPreviewed;
            ApplicationLauncher.ApplicationDeactivated += OnApplicationDeactivated;
        }

        /// <summary>
        /// Removes handlers for Application activation events.
        /// </summary>
        private void RemoveActivationHandlers()
        {
            // Unsubscribe from surface application activation events
            ApplicationLauncher.ApplicationActivated -= OnApplicationActivated;
            ApplicationLauncher.ApplicationPreviewed -= OnApplicationPreviewed;
            ApplicationLauncher.ApplicationDeactivated -= OnApplicationDeactivated;
        }

        /// <summary>
        /// This is called when application has been activated.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void OnApplicationActivated(object sender, EventArgs e)
        {
            //TODO: enable audio, animations here
        }

        /// <summary>
        /// This is called when application is in preview mode.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void OnApplicationPreviewed(object sender, EventArgs e)
        {
            //TODO: Disable audio here if it is enabled

            //TODO: optionally enable animations here
        }

        /// <summary>
        ///  This is called when application has been deactivated.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void OnApplicationDeactivated(object sender, EventArgs e)
        {
            //TODO: disable audio, animations here
        }
    }
}